@@ -4,6 +4,9 @@ import odoo_connect.format
 
 from . import odoo_rpc
 
+__doc__ = """Interact more easily with Odoo records."""
+
+
 """Cache of read values"""
 GLOBAL_CACHE: Dict[odoo_rpc.OdooModel, Dict[int, Dict[str, Any]]] = {}
 
@@ -122,18 +125,19 @@ class Instance:
         relation = prop.get('relation')
         if relation:
             model = self.__model.odoo.get_model(relation)
-            ids = set(i for v in values for i in v or [] if isinstance(i, int) and i)
+            # value is either list[int] (many) or list[tuple[int, str]|False] (one)
+            ids = set(i for v in values for i in (v or []) if isinstance(i, int) and i)
             return Instance(model, list(ids))
         return values
 
-    def cache(self, fields: List[str] = [], computed=True, exists=False) -> "Instance":
+    def cache(self, fields: List[str] = [], computed=False, exists=False) -> "Instance":
         """Cache the record fields and return self"""
         fieldset = set(self._default_fields(computed=computed) + fields)
         model_cache = self.__cache()
         # find missing ids, when missing in cache or field missing in cache
         # read all at once to have more consistency and avoid roundtrips
         missing_ids = set(i for i in self.__ids if fieldset - model_cache.get(i, {}).keys())
-        # an exists check is not needed because read() will return only existing rows
+        # an exists() check is not needed because read() will return only existing rows
         if not missing_ids:
             return self
         for d in self.__model.read(list(missing_ids), list(fieldset)):
@@ -146,7 +150,7 @@ class Instance:
 
     def read(self, *, check_fields: List[str] = []) -> List[Dict[str, Any]]:
         """Read the data"""
-        self.cache(fields=check_fields, computed=False)
+        self.cache(fields=check_fields)
         model_cache = self.__cache()
         try:
             return [model_cache[i] for i in self.__ids]
