@@ -1,10 +1,12 @@
 import logging
+import random
 import re
-from abc import ABC, abstractmethod
 from typing import Any, Dict, List, Optional, Union
 
+import requests
+
 __doc__ = """
-Base class for Odoo RPC.
+JSON-RPC class for Odoo RPC.
 """
 
 
@@ -50,47 +52,75 @@ class OdooServerError(RuntimeError):
         return dat.get('debug')
 
 
-class OdooClientBase(ABC):
+class OdooClient:
     """Odoo server connection"""
 
     url: str
     _models: Dict[str, "OdooModel"]
     _version: Dict[str, Any]
     _database: str
+    _username: str
+    _password: str
+    _uid: Optional[int]
 
     def __init__(
         self,
         *,
         url: str,
-        database: str,
-        username: str = None,
-        password: str = None,
+        database: Optional[str] = None,
         **_kwargs,
     ):
-        """Create new connection and authenicate when username is given."""
-        log = logging.getLogger(__name__)
+        """Create new connection."""
         self.url = url
-        self._database = database
-        log.info(
-            "Odoo connection (protocol: [%s]) initialized [%s], db: [%s]",
-            self.protocol,
+        self._database = database or ''
+        self._models = {}
+        self._version = {}
+        self._username = ''
+        self._password = ''
+        self._uid = None
+        self._init_session()
+        if not database:
+            self._database = self._init_default_database()
+        assert self._database
+        logging.getLogger(__name__).info(
+            "Odoo connection initialized [%s], db: [%s]",
             self.url,
             self.database,
         )
-        if username:
-            self.authenticate(username, password)
-            log.info("Login successful [%s], [%s] uid: %d", self.url, self.username, self._uid)
-        else:
-            self.authenticate('', None)
-        self._models = {}
-        self._version = {}
 
-    def authenticate(self, username: str, password: Optional[str]):
+    def _init_session(self):
+        """Initialize the session"""
+        self.__json_url = urljoin(self.url, "jsonrpc")
+        self.session = requests.Session()
+
+    def _init_default_database(self) -> str:
+        """Gets the default database from the server"""
+        log = logging.getLogger(__name__)
+        log.debug("Lookup the default database for [%s]", self.url)
+        # Get the default
+        try:
+            db = self._call("db", "monodb")
+            if isinstance(db, str) and db:
+                return db
+        except OdooServerError:
+            pass
+        # Try to list databases
+        dbs = self.list_databases()
+        if len(dbs) == 1:
+            return dbs[0]
+        # Fail
+        raise OdooServerError('Cannot determine the database for [%s]' % self.url)
+
+    def authenticate(self, username: str, password: str):
         """Authenticate with username and password"""
+        log = logging.getLogger(__name__)
+        old_username = self._username
+        self._uid = None
         self._username = username
         self._password = password
         if not username:
-            self._uid = None
+            if old_username:
+                log.info('Logged out [%s]' % self.url)
             return
         user_agent_env = {}  # type: ignore
         self._uid = self._call(
@@ -103,11 +133,25 @@ class OdooClientBase(ABC):
         )
         if not self._uid:
             raise OdooServerError('Failed to authenticate user %s' % username)
+        log.info("Login successful [%s], [%s] uid: %d", self.url, self.username, self._uid)
+
+    def _json_rpc(self, method: str, params: Any):
+        """Make a jsonrpc call"""
+        data = {
+            "jsonrpc": "2.0",
+            "method": method,
+            "params": params,
+            "id": random.randint(0, 1000000000),
+        }
+        resp = self.session.post(self.__json_url, json=data)
+        resp.raise_for_status()
+        reply = resp.json()
+        if reply.get("error"):
+            raise OdooServerError(reply["error"])
+        return reply.get("result", None)
 
-    @abstractmethod
     def _call(self, service: str, method: str, *args):
-        """Execute a method on a service"""
-        raise NotImplementedError
+        return self._json_rpc("call", {"service": service, "method": method, "args": args})
 
     def _execute_kw(self, model: str, method: str, *args, **kw):
         """Execute a method on a model"""
@@ -192,13 +236,12 @@ class OdooClientBase(ABC):
         return self.version()['server_version_info'][0]
 
     @property
-    @abstractmethod
     def protocol(self) -> str:
         """Get protocol used"""
-        return "unknown"
+        return "jsonrpc"
 
     def is_connected(self) -> bool:
-        """Check if we are connected"""
+        """Check if the authentication is done"""
         return self._uid is not None
 
     @property
@@ -228,6 +271,13 @@ class OdooClientBase(ABC):
         """Get database name"""
         return self._database
 
+    @database.setter
+    def database(self, database: str):
+        if database is None:
+            raise ValueError('Cannot set database: None')
+        self.authenticate('', '')  # log out first
+        self._database = database
+
     def __getitem__(self, model: str) -> "OdooModel":
         """Alias for get_model"""
         return self.get_model(model)
@@ -240,7 +290,7 @@ class OdooClientBase(ABC):
 class OdooModel:
     """Odoo model (object) RPC functions"""
 
-    def __init__(self, odoo: OdooClientBase, model: str):
+    def __init__(self, odoo: OdooClient, model: str):
         """Initialize the model instance.
 
         :param odoo: Odoo instance
